@@ -84,19 +84,9 @@ class Element(Function):
 
         # Switch modes
 
-        if mode == "Single fire":
+        if mode == "Delay":
 
-            ############################
-            #           None           #
-            ############################
-
-            recordDone = Record(None, message='Trigger: {:04d}'.format(self.config['Identifier']))
-            self.return_queue.put(recordDone)
-            return
-
-        elif mode == "Single fire, delayed":
-
-            self.singleFireDelayed()
+            self.delayed()
             return
 
         elif mode == "Interval":
@@ -140,7 +130,7 @@ class Element(Function):
             return
 
 
-    def singleFireDelayed(self):
+    def delayed(self):
 
         ############################
         #   Single fire, delayed   #
@@ -161,7 +151,7 @@ class Element(Function):
 
             countdown -= 1
 
-        recordDone = Record(data=None, message='Trigger: {:04d}'.format(self.config['Identifier']))    
+        recordDone = Record(data=None, message='>Trigger<   ProcHdl::{:04d}'.format(self.config['Identifier']))   
         self.return_queue.put(recordDone)    
 
     def intervalScheduler(self):
@@ -180,7 +170,7 @@ class Element(Function):
 
             if countdown <= 0:
                 countdown = self.interval / self.tick
-                recordDone = Record(data=None, message='Trigger: {:04d}'.format(self.config['Identifier']))    
+                recordDone = Record(data=None, message='>Trigger<   ProcHdl::{:04d}'.format(self.config['Identifier']))   
                 self.return_queue.put(recordDone)
             else:
 
@@ -232,7 +222,7 @@ class Element(Function):
 
                 if countdown <= 0:
 
-                    recordDone = Record(data=None, message='Trigger: {:04d}'.format(self.config['Identifier']))    
+                    recordDone = Record(data=None, message='>Trigger<   ProcHdl::{:04d}'.format(self.config['Identifier']))   
                     self.return_queue.put(recordDone)
                     nState = 4 # Go to interval mode
                 else:
@@ -257,7 +247,7 @@ class Element(Function):
 
                 if countdown <= 0:
                     countdown = self.interval / self.tick
-                    recordDone = Record(data=None, message='Trigger: {:04d}'.format(self.config['Identifier']))    
+                    recordDone = Record(data=None, message='>Trigger<   ProcHdl::{:04d}'.format(self.config['Identifier']))   
                     self.return_queue.put(recordDone)
                 else:
 
@@ -316,7 +306,7 @@ class Element(Function):
 
                 if countdown <= 0:
 
-                    recordDone = Record(data=None, message='Trigger: {:04d}'.format(self.config['Identifier']))    
+                    recordDone = Record(data=None, message='>Trigger<   ProcHdl::{:04d}'.format(self.config['Identifier']))   
                     self.return_queue.put(recordDone)
                     nState = 0 # Go to interval mode
                 else:
@@ -332,10 +322,6 @@ class Element(Function):
             if bExit:
                 return
 
-
-
-
-
     def onEveryFullInterval(self):
         
         ############################
@@ -381,7 +367,7 @@ class Element(Function):
                 #countdown -= 1
 
                 if  time.second % self.interval == 0 and lastFired != time.second:
-                    recordDone = Record(data=None, message='Trigger: {:04d}'.format(self.config['Identifier']))    
+                    recordDone = Record(data=None, message='>Trigger<   ProcHdl::{:04d}'.format(self.config['Identifier']))    
                     self.return_queue.put(recordDone)
                     countdown = self.interval / self.tick
                     lastFired = time.second
@@ -412,7 +398,7 @@ class Element(Function):
 
 
                 if  time.minute % (self.interval / 60) == 0 and time.second == 0:
-                    recordDone = Record(data=None, message='Trigger: {:04d}'.format(self.config['Identifier']))    
+                    recordDone = Record(data=None, message='>Trigger<   ProcHdl::{:04d}'.format(self.config['Identifier']))    
                     self.return_queue.put(recordDone)
                     countdown = self.interval / self.tick
 
@@ -447,7 +433,7 @@ class Element(Function):
 
 
                 if  time.minute % (self.interval / 60) == 0 and time.second == 0:
-                    recordDone = Record(data=None, message='Trigger: {:04d}'.format(self.config['Identifier']))    
+                    recordDone = Record(data=None, message='>Trigger<   ProcHdl::{:04d}'.format(self.config['Identifier']))    
                     self.return_queue.put(recordDone)
                     countdown = self.interval / self.tick
 
@@ -512,9 +498,6 @@ class Element(Function):
                 countdown -= 1
 
                 if countdown <= 0:
-
-                    #recordDone = Record(data=None, message='Trigger: {:04d}'.format(self.config['Identifier']))    
-                    #self.return_queue.put(recordDone)
                     nState = 4 # Go to interval mode
                 else:
 
@@ -551,7 +534,7 @@ class Element(Function):
 
 
                 if  time.second % self.interval == 0 and lastFired != time.second:
-                    recordDone = Record(data=None, message='Trigger: {:04d}'.format(self.config['Identifier']))    
+                    recordDone = Record(data=None, message='>Trigger<   ProcHdl::{:04d}'.format(self.config['Identifier']))    
                     self.return_queue.put(recordDone)
                     countdown = self.interval / self.tick
                     lastFired = time.second
@@ -586,7 +569,7 @@ class Element(Function):
                 countdown -= 1
 
                 if  time.minute % (self.interval / 60) == 0 and time.second == 0:
-                    recordDone = Record(data=None, message='Trigger: {:04d}'.format(self.config['Identifier']))    
+                    recordDone = Record(data=None, message='>Trigger<   ProcHdl::{:04d}'.format(self.config['Identifier']))    
                     self.return_queue.put(recordDone)
                     countdown = self.interval / self.tick
 
@@ -627,7 +610,7 @@ class Element(Function):
                 countdown -= 1
 
                 if  time.minute % (self.interval / 60) == 0 and time.second == 0:
-                    recordDone = Record(data=None, message='Trigger: {:04d}'.format(self.config['Identifier']))    
+                    recordDone = Record(data=None, message='>Trigger<   ProcHdl::{:04d}'.format(self.config['Identifier']))  
                     self.return_queue.put(recordDone)
                     countdown = self.interval / self.tick
 
